#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-2IjA4J7jKmb3rvOA3dYC2H
key:                  temporary-1.3-2IjA4J7jKmb3rvOA3dYC2H
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  641cb3c134c670fe673d3fb6ddd68ea9
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-8.10.5/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/temporary-1.3
hs-libraries:         HStemporary-1.3-2IjA4J7jKmb3rvOA3dYC2H
depends:
    base-4.14.2.0 directory-1.3.6.0 exceptions-0.10.4 filepath-1.4.2.1
    random-1.2.0-BSVdQCE475yEKcUUPfL4ub transformers-0.5.6.2
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

